API
---

VSG was written to be included in other tools.
The command line script provides one means of using VSG.
It also provides an example of how to use the API.

There are two main modules you will use when incorporating VSG into another program:

.. toctree::

   vsg.vhdlFile
   vsg.rule_list
